

/*******************************************************************************
*              (c), Copyright 2001, Marvell International Ltd.                 *
* THIS CODE CONTAINS CONFIDENTIAL INFORMATION OF MARVELL SEMICONDUCTOR, INC.   *
* NO RIGHTS ARE GRANTED HEREIN UNDER ANY PATENT, MASK WORK RIGHT OR COPYRIGHT  *
* OF MARVELL OR ANY THIRD PARTY. MARVELL RESERVES THE RIGHT AT ITS SOLE        *
* DISCRETION TO REQUEST THAT THIS CODE BE IMMEDIATELY RETURNED TO MARVELL.     *
* THIS CODE IS PROVIDED "AS IS". MARVELL MAKES NO WARRANTIES, EXPRESS, IMPLIED *
* OR OTHERWISE, REGARDING ITS ACCURACY, COMPLETENESS OR PERFORMANCE.           *
********************************************************************************
* artOverMpsc.h - this file has all the declarations 
* that enable UART on MPSC port 
*
* DESCRIPTION                                                               
*
* DEPENDENCIES:
*       None.
*
*******************************************************************************/
          
#ifndef _UART_OVER_MPSC_
#define _UART_OVER_MPSC_

#include "core.h"

#define NUMBER_OF_TX_DESCRIPTORS						2000
#define NUMBER_OF_RX_DESCRIPTORS						2000

#define RX_DESCRIPTOR_SIZE								0x20
#define TX_DESCRIPTOR_SIZE								0x20

/* this address can be any free uncached memory */
#define BASE_ADDRESS_RX_DESCRIPTORS						0x90000 
#define BASE_ADDRESS_TX_DESCRIPTORS						BASE_ADDRESS_RX_DESCRIPTORS+NUMBER_OF_RX_DESCRIPTORS*RX_DESCRIPTOR_SIZE


#define MRR_REG_VALUE									0x7ffe38
#define SERIAL_PORT_MULTIPLEX_REGISTER_VALUE			0x1102 /* connect MPSC0 + 3 ports of RMII */
#define DEFAULT_UART_BRG								0x00010000 /* BCLK_in CDV=0 En=1*/

/* UART */
#define DEFAULT_UART_MMCRL								0x000004c4
#define DEFAULT_UART_MMCRH								0x064007f8 /* rcdv=3 , rdw=1 , tcdv=3 */
#define DEFAULT_UART_MPCR								0x00003000 /* cl=3 */

#define DEFAULT_UART_CHR1								0x003000ab
#define DEFAULT_UART_CHR2								0x80000000 
#define DEFAULT_UART_CHR3								0x00000000
#define DEFAULT_UART_CHR4								0x00000000 /* accept all addresses */
#define DEFAULT_UART_CHR5								0x00000000
#define DEFAULT_UART_CHR6								0x00000000
#define DEFAULT_UART_CHR7								0x00000000


#define OWNER_BY_GT										1<<31
#define ENABLE_INTERRUPT								1<<23
#define FIRST											1<<17
#define LAST											1<<16
#define ERROR_SUMMARY									1<<15
#define PREAMBLE										1<<18
#define PADDING											1<<18
#define GENERATE_CRC									1<<22

/* this macros are used to enable access to SDMA_CONFIGURATION */            
#define SINGLE_FRAME_MODE								1<<1
#define RECEIVE_FIFO_THRESHOLD							1
#define BURST_SIZE										3<<12

/* this macros are used to enable access to MPSC_SDCMR */            
#define ABORT_RECEIVE									1<<15
#define STOP_TRANSMIT									1<<16
#define ENABLE_RX_DMA									1<<7
#define TX_DEMAND										1<<23
#define ABORT_TRANSMIT									1<<31

/* this macros are used to enable access to MPSC_CHANNEL_STRUCT */            
#define ENTER_HUNT                          1<<31
#define ABORT_RECEPTION                     1<<23
#define ABORT_TRANSMITION                   1<<7
#define RX_ENTER_HUNT_STATE                 1<<5

#define CHANNELS_DIFFERENCE_OFFSETS						0x2000
#define MPSC_GAP										0x01040


typedef unsigned int									RX_COMMAND;

typedef struct SdmaRxDesc
{
	unsigned int			bufsize	:16;
	unsigned int			bytecnt	:16;
	RX_COMMAND				cmd_sts; 
	unsigned int			next_desc_ptr; 
	unsigned int			buf_ptr;  
	unsigned int			buffer;  

} RX_DESC;

typedef unsigned int									TX_COMMAND;

typedef struct SdmaTxDesc
{    
	unsigned int		    bytecnt	:16;
	unsigned int		    shadow	:16;
	TX_COMMAND				cmd_sts;
    unsigned int		    next_desc_ptr; 
	unsigned int		    buf_ptr;
	unsigned int			buffer;  
} TX_DESC;

unsigned int fixAddressOf64Bit(unsigned int addr);
char uartOverMpscGetc();
bool uartOverMpscInit(int port);
bool uartOverMpscPutc(char charToPut);
char uartOverMpscGetChar();


#endif
